# Generated by Django 4.2.21 on 2025-05-19 17:15

from django.db import migrations, connection


class Migration(migrations.Migration):

    dependencies = [
        ('integrated_channel', '0035_genericlearnerdatatransmissionaudit_is_transmitted'),
    ]

    database_operations = []
    if connection.vendor != 'sqlite':
        database_operations.extend([
            migrations.RenameIndex(
                model_name='contentmetadataitemtransmission',
                new_name='customer_code_plugin_id_idx',
                old_fields=('enterprise_customer', 'integrated_channel_code', 'plugin_configuration_id', 'content_id'),
            ),
            migrations.RenameIndex(
                model_name='orphanedcontenttransmissions',
                new_name='channel_plugin_resolved_idx',
                old_fields=('integrated_channel_code', 'plugin_configuration_id', 'resolved'),
            )
        ])

    operations = [
        migrations.SeparateDatabaseAndState(
            database_operations=database_operations,
            state_operations=[
                migrations.RenameIndex(
                    model_name='contentmetadataitemtransmission',
                    new_name='customer_code_plugin_id_idx',
                    old_fields=('enterprise_customer', 'integrated_channel_code', 'plugin_configuration_id', 'content_id'),
                ),
                migrations.RenameIndex(
                    model_name='orphanedcontenttransmissions',
                    new_name='channel_plugin_resolved_idx',
                    old_fields=('integrated_channel_code', 'plugin_configuration_id', 'resolved'),
                ),
            ],
        )
    ]
